using Articy.Unity;
using Articy.Unity.Interfaces;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class WorldSpaceArticyStoryline : MonoBehaviour, IArticyFlowPlayerCallbacks {
    public IList<Branch> currentBranches;
    
    //previously ApplyTransition
    //is called at every "Pause" of the Flow Player (Pause = Dialogue Nodes,...)
    public void OnFlowPlayerPaused(IFlowObject currentNode) {
        var dialogueBox = this.gameObject.GetComponent<WorldSpaceDialogueBox>();

        if (currentNode != null) {
            var objWithText = currentNode as IObjectWithText;
            if (objWithText != null) {
                dialogueBox.SetText(objWithText.Text);
            }

            var objSpeaker = currentNode as IObjectWithSpeaker;
            if (objSpeaker != null) {
                var speakerDisplayName = objSpeaker.Speaker as IObjectWithDisplayName;
                if (speakerDisplayName != null) {
                    dialogueBox.SetActor(speakerDisplayName.DisplayName);
                }
                else {
                    dialogueBox.SetActor(string.Empty);
                }
            }
            else {
                dialogueBox.SetActor(string.Empty);
            }
        }
        else {
            dialogueBox.ClearUI();
        }
    }

    //is called with every new Dialogue Node and returns its branches
    public void OnBranchesUpdated(IList<Branch> branches) {
        currentBranches = branches;
        if (currentBranches.Count > 0) {
            this.gameObject.GetComponent<WorldSpaceDialogueBox>().SetTransitions(currentBranches);
        }
        else {
            Destroy(this.gameObject);
        }
    }

    //used by the Buttons in the DialogueBox script
    public void ApplyTransition(int count) {
        this.gameObject.GetComponent<WorldSpaceDialogueBox>().ClearUI();
        this.gameObject.GetComponent<ArticyFlowPlayer>().Play(currentBranches[count]);
    }
}